@@ -59,8 +59,8 @@ import java.util.Arrays;
 import java.util.Collections;
 import java.util.Comparator;
 import java.util.Map;
+import java.util.Map.Entry;
 import java.util.Set;
-
 import javax.management.AttributeNotFoundException;
 import javax.management.InstanceNotFoundException;
 import javax.management.IntrospectionException;
@@ -75,7 +75,6 @@ import javax.management.ObjectInstance;
 import javax.management.ObjectName;
 import javax.management.ReflectionException;
 import javax.management.openmbean.CompositeDataSupport;
-
 import com.openexchange.admin.console.AdminParser.NeededQuadState;
 import com.openexchange.admin.rmi.exceptions.InvalidDataException;
 
@@ -132,10 +131,6 @@ public class StatisticTools extends AbstractJMXTools {
     private static final char OPT_CACHE_STATS_SHORT = 'j';
     private static final String OPT_CACHE_STATS_LONG = "cachestats";
 
-    private static final String OPT_AJPTHREADS_STATS_LONG = "ajpthreadsstats";
-
-    private static final String OPT_AJPTASKS_STATS_LONG = "ajptasksstats";
-
     private static final String OPT_GENERAL_STATS_LONG = "generalstats";
 
     private static final String OPT_MAILINTERFACE_STATS_LONG = "mailinterfacestats";
@@ -152,7 +147,7 @@ public class StatisticTools extends AbstractJMXTools {
 
     private static final char OPT_NIO_BUFFER_STATS_SHORT = 'n';
     private static final String OPT_NIO_BUFFER_STATS_LONG = "niobufferstats";
-
+    
     private static final char OPT_RT_BUFFER_STATS_SHORT= 'R';
     private static final String OPT_RT_BUFFER_STATS_LONG = "rtstats";
 
@@ -174,8 +169,6 @@ public class StatisticTools extends AbstractJMXTools {
     private CLIOption documentconverterstats = null;
     private CLIOption officestats = null;
     private CLIOption eventadminstats = null;
-    private CLIOption ajpthreadsstats = null;
-    private CLIOption ajptasksstats = null;
     private CLIOption generalstats = null;
     private CLIOption mailinterfacestats = null;
     private CLIOption poolingstats = null;
@@ -184,6 +177,7 @@ public class StatisticTools extends AbstractJMXTools {
     private CLIOption overviewstats = null;
     private CLIOption memorypoolstats = null;
     private CLIOption niobufferstats = null;
+    private CLIOption rtstats = null;
 
     /**
      * Option for garbage collection statistics
@@ -265,7 +259,8 @@ public class StatisticTools extends AbstractJMXTools {
             System.out.print(showGcData(mbc));
             System.out.print(getStats(mbc, "com.openexchange.usm.session", "name", "com.openexchange.usm.session.impl.USMSessionInformation"));
             System.out.print(showEventAdminData(mbc));
-            System.out.println(showNioBufferData(mbc));
+            System.out.print(showNioBufferData(mbc));
+            System.out.println(showRtData(mbc));
             count++;
         }
         if (null != parser.getOptionValue(this.showoperation) && 0 == count) {
@@ -296,14 +291,6 @@ public class StatisticTools extends AbstractJMXTools {
             System.out.print(showOfficeData(mbc));
             count++;
         }
-        if (null != parser.getOptionValue(this.ajpthreadsstats) && 0 == count) {
-            System.out.print(showAJPv13ServerThreadsMonitor(mbc));
-            count++;
-        }
-        if (null != parser.getOptionValue(this.ajptasksstats) && 0 == count) {
-            System.out.print(showAJPv13TaskMonitor(mbc));
-            count++;
-        }
         if (null != parser.getOptionValue(this.generalstats) && 0 == count) {
             System.out.print(showGeneralMonitor(mbc));
             count++;
@@ -335,10 +322,14 @@ public class StatisticTools extends AbstractJMXTools {
             System.out.print(showNioBufferData(mbc));
             count++;
         }
+        if (null != parser.getOptionValue(this.rtstats) && 0 == count) {
+            System.out.print(showRtData(mbc));
+            count++;
+        }
         if (0 == count) {
             System.err.println(new StringBuilder("No option selected (").append(OPT_STATS_LONG).append(", ").append(
                 OPT_RUNTIME_STATS_LONG).append(", ").append(OPT_OS_STATS_LONG).append(", ").append(OPT_THREADING_STATS_LONG).append(
-                ", ").append(OPT_ALL_STATS_LONG).append(", sessionstats)"));
+                    ", ").append(OPT_ALL_STATS_LONG).append(", sessionstats)"));
             parser.printUsage();
         } else if (count > 1) {
             System.err.println("More than one of the stat options given. Using the first one only");
@@ -575,8 +566,6 @@ public class StatisticTools extends AbstractJMXTools {
             "shows the OSGi EventAdmin stats",
             false,
             NeededQuadState.notneeded);
-        this.ajpthreadsstats = setLongOpt(parser, OPT_AJPTHREADS_STATS_LONG, "shows the AJP Thread stats", false, false);
-        this.ajptasksstats = setLongOpt(parser, OPT_AJPTASKS_STATS_LONG, "shows the AJP Tasks stats", false, false);
         this.generalstats = setLongOpt(parser, OPT_GENERAL_STATS_LONG, "shows the open-xchange general stats", false, false);
         this.mailinterfacestats = setLongOpt(parser, OPT_MAILINTERFACE_STATS_LONG, "shows the open-xchange mailinterface stats", false, false);
         this.poolingstats = setLongOpt(parser, OPT_POOLING_STATS_LONG, "shows the open-xchange pooling stats", false, false);
@@ -591,6 +580,7 @@ public class StatisticTools extends AbstractJMXTools {
             "shows the NIO buffer stats",
             false,
             NeededQuadState.notneeded);
+        this.rtstats = setShortLongOpt(parser, OPT_RT_BUFFER_STATS_SHORT, OPT_RT_BUFFER_STATS_LONG, "shows stats for the realtime component", false, NeededQuadState.notneeded);
 
 
     }
@@ -609,7 +599,6 @@ public class StatisticTools extends AbstractJMXTools {
         sb.append(showGeneralMonitor(con));
         sb.append(showMailInterfaceMonitor(con));
         sb.append(showPooling(con));
-        sb.append(showRateLimiterMonitor(con));
         return sb.toString();
     }
 
@@ -625,18 +614,6 @@ public class StatisticTools extends AbstractJMXTools {
         return getStats(con, "com.openexchange.monitoring:name=GeneralMonitor");
     }
 
-    private static StringBuffer showAJPv13TaskMonitor(MBeanServerConnection con) throws IOException, InstanceNotFoundException, MBeanException, AttributeNotFoundException, ReflectionException, IntrospectionException, MalformedObjectNameException {
-        return getStats(con, "com.openexchange.monitoring:name=AJPv13TaskMonitor");
-    }
-
-    private static StringBuffer showAJPv13ServerThreadsMonitor(MBeanServerConnection con) throws IOException, InstanceNotFoundException, MBeanException, AttributeNotFoundException, ReflectionException, IntrospectionException, MalformedObjectNameException {
-        return getStats(con, "com.openexchange.monitoring:name=AJPv13ServerThreadsMonitor");
-    }
-
-    private static StringBuffer showRateLimiterMonitor(MBeanServerConnection con) throws IOException, InstanceNotFoundException, MBeanException, AttributeNotFoundException, ReflectionException, IntrospectionException, MalformedObjectNameException {
-        return getStats(con, "com.openexchange.monitoring:name=RateLimiterMonitor");
-    }
-
     private static StringBuffer showCallMonitor(MBeanServerConnection con) throws IOException, InstanceNotFoundException, MBeanException, AttributeNotFoundException, ReflectionException, IntrospectionException, MalformedObjectNameException {
         return getStats(con, "com.openexchange.admin.monitor:name=CallMonitor");
     }
@@ -689,7 +666,7 @@ public class StatisticTools extends AbstractJMXTools {
          */
         StringBuilder sb = new StringBuilder();
         for (String type : new String[] { "HazelcastInstance", "HazelcastInstance.Node", "HazelcastInstance.EventService",
-            "HazelcastInstance.ClientEngine", "HazelcastInstance.ConnectionManager", "HazelcastInstance.PartitionServiceMBean" }) {
+            "HazelcastInstance.ClientEngine", "HazelcastInstance.ConnectionManager" }) {
             for (ObjectInstance mbean : mbc.queryMBeans(new ObjectName("com.hazelcast:type=" + type + ",*"), null)) {
                 ObjectName objectName = mbean.getObjectName();
                 MBeanInfo beanInfo = mbc.getMBeanInfo(objectName);
@@ -741,7 +718,7 @@ public class StatisticTools extends AbstractJMXTools {
             result = mbc.invoke(toolkitName, "supportsPartitionReplicas", new Object[0], new String[0]);
             if (null == result || false == Boolean.class.isInstance(result) || Boolean.FALSE.equals(result)) {
                 return sb.append("[No owner for all configured partition replicas detected, unable to retrieve map statistics]")
-                   .append(LINE_SEPARATOR).toString();
+                    .append(LINE_SEPARATOR).toString();
             }
         }
         /*
@@ -783,8 +760,8 @@ public class StatisticTools extends AbstractJMXTools {
         for (final GrizzlyMBean grizzlyMBean : GrizzlyMBean.values()) {
             final ObjectName objectName = new ObjectName(grizzlyMBean.getObjectName());
             final Set<ObjectInstance> mBeans = mbeanServerConnection.queryMBeans(objectName, null);
-            // Iterate over the found MBeans and print the desired attributes for this MBean. If no MBeans are found (jmx disabled, ajp
-            // backend in use) nothig will be printed to stdout
+            // Iterate over the found MBeans and print the desired attributes for this MBean. If no MBeans are found (jmx disabled) nothig
+            // will be printed to stdout
             for (final ObjectInstance mBean : mBeans) {
                 for (final String attribute : grizzlyMBean.getAttributes()) {
                     sb.append(objectName);
@@ -922,7 +899,7 @@ public class StatisticTools extends AbstractJMXTools {
         .append(getStats(mbeanServerConnection, "java.nio:type=BufferPool,name=mapped"))
         .toString();
     }
-
+    
     static String showRtData(final MBeanServerConnection mbeanServerConnection) {
         String runLoopFillSum = "RunLoopFillSum";
         StringBuilder sb = new StringBuilder();
@@ -931,7 +908,7 @@ public class StatisticTools extends AbstractJMXTools {
             Object fillSum = mbeanServerConnection.getAttribute(objectName, runLoopFillSum);
             if (fillSum instanceof Map) {
                 Map<?, ?> fillSums = Map.class.cast(fillSum);
-                for (Map.Entry<?, ?> entry : fillSums.entrySet()) {
+                for (Entry<?, ?> entry : fillSums.entrySet()) {
                     sb.append(objectName);
                     sb.append(',');
                     sb.append(runLoopFillSum);
