@@ -79,7 +79,12 @@ public class List extends ListCore {
 
     @Override
     protected User[] maincall(final AdminParser parser, final OXUserInterface oxusr, final String search_pattern, final boolean ignoreCase, final Context ctx, final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException, InvalidDataException, DatabaseUpdateException, NoSuchUserException {
-        final User[] allusers = ignoreCase ? oxusr.listCaseInsensitive(ctx, search_pattern, auth) : oxusr.list(ctx, search_pattern, auth);
+        return maincall(parser, oxusr, search_pattern, ignoreCase, ctx, auth, false, false);
+    }
+
+    @Override
+    protected User[] maincall(final AdminParser parser, final OXUserInterface oxusr, final String search_pattern, final boolean ignoreCase, final Context ctx, final Credentials auth, final boolean includeGuests, final boolean excludeUsers) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException, InvalidDataException, DatabaseUpdateException, NoSuchUserException {
+        final User[] allusers = ignoreCase ? oxusr.listCaseInsensitive(ctx, search_pattern, auth, includeGuests, excludeUsers) : oxusr.list(ctx, search_pattern, auth, includeGuests, excludeUsers);
         if( allusers.length == 0 ) {
             return new User[0];
         }
@@ -88,6 +93,8 @@ public class List extends ListCore {
 
     @Override
     protected void setFurtherOptions(final AdminParser parser) {
+        setIncludeGuestsOption(parser);
+        setExcludeUsersOption(parser);
     }
 
     @Override
