@@ -115,7 +115,17 @@ public abstract class ListCore extends UserAbstraction {
                 ignoreCase = Boolean.FALSE;
             }
 
-            final User[] allusers = maincall(parser, oxusr, pattern, ignoreCase.booleanValue(), ctx, auth);
+            Boolean includeGuests = (Boolean) parser.getOptionValue(this.includeGuestsOption);
+            if (null == includeGuests) {
+                includeGuests = Boolean.FALSE;
+            }
+
+            Boolean excludeUsers = (Boolean) parser.getOptionValue(this.excludeUsersOption);
+            if (null == excludeUsers) {
+                excludeUsers = Boolean.FALSE;
+            }
+
+            final User[] allusers = maincall(parser, oxusr, pattern, ignoreCase.booleanValue(), ctx, auth, includeGuests.booleanValue(), excludeUsers.booleanValue());
 
             if (null != parser.getOptionValue(this.csvOutputOption)) {
                 // map user data to corresponding module access
@@ -138,6 +148,8 @@ public abstract class ListCore extends UserAbstraction {
 
     protected abstract User[] maincall(final AdminParser parser, final OXUserInterface oxusr, final String search_pattern, final boolean ignoreCase, final Context ctx, final Credentials auth) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException, InvalidDataException, DatabaseUpdateException, NoSuchUserException, DuplicateExtensionException;
 
+    protected abstract User[] maincall(final AdminParser parser, final OXUserInterface oxusr, final String search_pattern, final boolean ignoreCase, final Context ctx, final Credentials auth, final boolean includeGuests, final boolean excludeUsers) throws RemoteException, StorageException, InvalidCredentialsException, NoSuchContextException, InvalidDataException, DatabaseUpdateException, NoSuchUserException, DuplicateExtensionException;
+
     /**
      * This method is used to define how a date value is transferred to string
      *
@@ -203,35 +215,60 @@ public abstract class ListCore extends UserAbstraction {
         }
 
 //        doOutput(new String[] { "3r", "30l", "30l", "14l" },
-        doOutput(new String[] { "r", "l", "l", "l" },
-                 new String[] { "Id", "Name", "Displayname", "Email" }, data);
+        doOutput(new String[] { "r", "l", "l", "l", "l", "l" },
+                 new String[] { "Id", "Name", "Displayname", "Email", "qmax", "qused" }, data);
     }
 
     private ArrayList<String> makeStandardData(final User user) {
         final ArrayList<String> res_data = new ArrayList<String>();
 
-        res_data.add(String.valueOf(user.getId())); // id
+        res_data.add(String.valueOf(user.getId()));// id
 
-        final String name = user.getName();
-        if (name != null && name.trim().length() > 0) {
-            res_data.add(name); // name
-        } else {
-            res_data.add(null); // name
+        {
+            final String name = user.getName();
+            if (name != null && name.trim().length() > 0) {
+                res_data.add(name);// name
+            } else {
+                res_data.add(null);// name
+            }
         }
 
-        final String displayname = user.getDisplay_name();
-        if (displayname != null && displayname.trim().length() > 0) {
-            res_data.add(displayname); // displayname
-        } else {
-            res_data.add(null); // displayname
+        {
+            final String displayname = user.getDisplay_name();
+            if (displayname != null && displayname.trim().length() > 0) {
+                res_data.add(displayname);// displayname
+            } else {
+                res_data.add(null);// displayname
+            }
         }
 
-        final String email = user.getPrimaryEmail();
-        if (email != null && email.trim().length() > 0) {
-            res_data.add(email); // email
-        } else {
-            res_data.add(null); // email
+        {
+            final String email = user.getPrimaryEmail();
+            if (email != null && email.trim().length() > 0) {
+                res_data.add(email);// email
+            } else {
+                res_data.add(null);// email
+            }
         }
+
+        {
+            final Long qmax = user.getMaxQuota();
+            if (null != qmax) {
+                res_data.add(qmax.toString());// qmax
+            } else {
+                res_data.add(null);// qmax
+            }
+        }
+
+        {
+            final Long qused = user.getUsedQuota();
+            if (null != qused) {
+                res_data.add(qused.toString());// qused
+            } else {
+                res_data.add(null);// qused
+            }
+        }
+
         return res_data;
     }
 
@@ -311,6 +348,8 @@ public abstract class ListCore extends UserAbstraction {
                     datarow.add((String)methodandnames.getMethod().invoke(user, (Object[]) null));
                 } else if (returntype.equals(JAVA_LANG_INTEGER)) {
                     datarow.add(String.valueOf(methodandnames.getMethod().invoke(user, (Object[]) null)));
+                } else if (returntype.equals(JAVA_LANG_LONG)) {
+                    datarow.add(String.valueOf(methodandnames.getMethod().invoke(user, (Object[]) null)));
                 } else if (returntype.equals(JAVA_LANG_BOOLEAN)) {
                     datarow.add(booleantostring((Boolean)methodandnames.getMethod().invoke(user, (Object[]) null)));
                 } else if (returntype.equals(JAVA_UTIL_DATE)) {
