@@ -52,7 +52,6 @@ package com.openexchange.admin.rmi.impl;
 import static com.openexchange.java.Autoboxing.I;
 import static com.openexchange.java.Autoboxing.I2i;
 import static com.openexchange.java.Autoboxing.i2I;
-import java.io.IOException;
 import java.net.URI;
 import java.net.URISyntaxException;
 import java.rmi.RemoteException;
@@ -62,6 +61,7 @@ import java.util.HashSet;
 import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Set;
+import java.util.concurrent.ExecutionException;
 import org.osgi.framework.BundleContext;
 import com.openexchange.admin.daemons.ClientAdminThread;
 import com.openexchange.admin.daemons.ClientAdminThreadExtended;
@@ -73,6 +73,7 @@ import com.openexchange.admin.rmi.dataobjects.Credentials;
 import com.openexchange.admin.rmi.dataobjects.Database;
 import com.openexchange.admin.rmi.dataobjects.Filestore;
 import com.openexchange.admin.rmi.dataobjects.MaintenanceReason;
+import com.openexchange.admin.rmi.dataobjects.Quota;
 import com.openexchange.admin.rmi.dataobjects.SchemaSelectStrategy;
 import com.openexchange.admin.rmi.dataobjects.User;
 import com.openexchange.admin.rmi.dataobjects.UserModuleAccess;
@@ -95,31 +96,68 @@ import com.openexchange.admin.storage.interfaces.OXContextStorageInterface;
 import com.openexchange.admin.storage.interfaces.OXUserStorageInterface;
 import com.openexchange.admin.storage.interfaces.OXUtilStorageInterface;
 import com.openexchange.admin.storage.sqlStorage.OXAdminPoolDBPoolExtension;
+import com.openexchange.admin.storage.utils.Filestore2UserUtil;
 import com.openexchange.admin.taskmanagement.TaskManager;
 import com.openexchange.admin.tools.AdminCache;
 import com.openexchange.admin.tools.DatabaseDataMover;
-import com.openexchange.admin.tools.FilestoreDataMover;
+import com.openexchange.admin.tools.filestore.FilestoreDataMover;
+import com.openexchange.admin.tools.filestore.PostProcessTask;
 import com.openexchange.caching.Cache;
 import com.openexchange.caching.CacheService;
 import com.openexchange.exception.OXException;
+import com.openexchange.filestore.FileStorages;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
 import com.openexchange.tools.pipesnfilters.Filter;
 
 public class OXContext extends OXContextCommonImpl implements OXContextInterface {
 
-    private static final org.slf4j.Logger LOGGER = org.slf4j.LoggerFactory.getLogger(OXContext.class);
+    /** The logger */
+    static final org.slf4j.Logger LOGGER = org.slf4j.LoggerFactory.getLogger(OXContext.class);
 
     private final OXAdminPoolDBPoolExtension pool;
 
-    public OXContext(final BundleContext context) throws StorageException {
+    /**
+     * Initializes a new {@link OXContext}.
+     *
+     * @param context The associated bundle context
+     */
+    public OXContext(final BundleContext context) {
         super(context);
         this.pool = new OXAdminPoolDBPoolExtension();
         LOGGER.debug("Class loaded: {}", this.getClass().getName());
     }
 
+    @Override
+    public Quota[] listQuotas(Context ctx, Credentials credentials) throws RemoteException, InvalidCredentialsException, NoSuchContextException, StorageException, InvalidDataException {
+        Credentials auth = credentials == null ? new Credentials("", "") : credentials;
+
+        new BasicAuthenticator().doAuthentication(auth);
+
+        try {
+            setIdOrGetIDFromNameAndIdObject(null, ctx);
+        } catch (final NoSuchObjectException e) {
+            throw new NoSuchContextException(e);
+        }
+
+        try {
+            if (!tool.existsContext(ctx)) {
+                throw new NoSuchContextException();
+            }
+
+            OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
+            return oxcox.listQuotas(ctx);
+        } catch (StorageException e) {
+            LOGGER.error("", e);
+            throw e;
+        } catch (NoSuchContextException e) {
+            LOGGER.error("", e);
+            throw e;
+        }
+    }
+
     @Override
     public void changeQuota(final Context ctx, final String sModule, final long quotaValue, final Credentials credentials) throws RemoteException, InvalidCredentialsException, NoSuchContextException, StorageException, InvalidDataException {
-        if (isEmpty(sModule)) {
+        if (com.openexchange.java.Strings.isEmpty(sModule)) {
             throw new InvalidDataException("No valid module specified.");
         }
 
@@ -157,9 +195,6 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                 throw new NoSuchContextException();
             }
 
-            final OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
-            oxcox.changeQuota(ctx, new ArrayList<String>(modules), quota, auth);
-
             // Trigger plugin extensions
             {
                 final PluginInterfaces pluginInterfaces = PluginInterfaces.getInstance();
@@ -170,6 +205,8 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                 }
             }
 
+            final OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
+            oxcox.changeQuota(ctx, new ArrayList<String>(modules), quota, auth);
         } catch (final StorageException e) {
             LOGGER.error("", e);
             throw e;
@@ -240,9 +277,6 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                 throw new NoSuchContextException();
             }
 
-            final OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
-            oxcox.changeCapabilities(ctx, capsToAdd, capsToRemove, capsToDrop, auth);
-
             // Trigger plugin extensions
             {
                 final PluginInterfaces pluginInterfaces = PluginInterfaces.getInstance();
@@ -253,6 +287,8 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                 }
             }
 
+            final OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
+            oxcox.changeCapabilities(ctx, capsToAdd, capsToRemove, capsToDrop, auth);
         } catch (final StorageException e) {
             LOGGER.error("", e);
             throw e;
@@ -286,7 +322,8 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         }
         LOGGER.debug(ctx.toString());
 
-        Set<String> loginMappings = null; // used for invalidating old login mappings in the cache
+        Context backup_ctx = null; // used for invalidating old login mappings in the cache
+
         try {
             if (!tool.existsContext(ctx)) {
                 throw new NoSuchContextException();
@@ -316,13 +353,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             }
 
             final OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
-
-            // Check if login-mappings are supposed to be changed
-            if (null != ctx.getLoginMappings()) {
-                // Load old ones for invalidation purpose
-                loginMappings = oxcox.getLoginMappings(ctx);
-            }
-
+            backup_ctx = oxcox.getData(ctx);
             oxcox.change(ctx);
         } catch (final StorageException e) {
             LOGGER.error("", e);
@@ -338,8 +369,9 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         try {
             final ContextStorage cs = ContextStorage.getInstance();
             cs.invalidateContext(ctx.getId().intValue());
+            final Set<String> loginMappings = backup_ctx.getLoginMappings();
             if (loginMappings != null && !loginMappings.isEmpty()) {
-                for (String loginMapping : loginMappings) {
+                for (final String loginMapping : loginMappings) {
                     cs.invalidateLoginInfo(loginMapping);
                 }
             }
@@ -462,10 +494,11 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             }
 
             oxcox.delete(ctx);
+            Filestore2UserUtil.removeFilestore2UserEntries(ctx.getId().intValue(), ClientAdminThread.cache);
             basicAuthenticator.removeFromAuthCache(ctx);
         } catch (final StorageException e) {
             LOGGER.error("", e);
-            throw new StorageException(e.getMessage());
+            throw e;
         } catch (final NoSuchContextException e) {
             LOGGER.error("", e);
             throw e;
@@ -722,6 +755,30 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         // END OF CACHE
     }
 
+    @Override
+    public Context getOwnData(Context ctx, Credentials credentials) throws RemoteException, InvalidCredentialsException, NoSuchContextException, StorageException, InvalidDataException {
+        Credentials auth = credentials == null ? new Credentials("", "") : credentials;
+        try {
+            try {
+                doNullCheck(ctx);
+            } catch (final InvalidDataException e1) {
+                LOGGER.error("One of the given arguments for getData is null", e1);
+                throw e1;
+            }
+
+            new BasicAuthenticator(context).doAuthentication(auth, ctx);
+
+            OXContextStorageInterface oxcox = OXContextStorageInterface.getInstance();
+            return oxcox.getData(new Context[] { ctx })[0];
+        } catch (final StorageException e) {
+            LOGGER.error("", e);
+            throw e;
+        } catch (final RuntimeException e) {
+            LOGGER.error("", e);
+            throw e;
+        }
+    }
+
     @Override
     public Context[] getData(final Context[] ctxs, final Credentials credentials) throws RemoteException, InvalidCredentialsException, NoSuchContextException, StorageException, InvalidDataException {
         final Credentials auth = credentials == null ? new Credentials("", "") : credentials;
@@ -1018,7 +1075,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
             throw e;
         }
 
-        new BasicAuthenticator(context).doAuthentication(auth);
+        new BasicAuthenticator().doAuthentication(auth);
 
         Context retval = null;
 
@@ -1045,56 +1102,63 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
                 throw new OXContextException("Unable to disable Context " + ctx.getIdAsString());
             }
 
-            oxcox.disable(ctx, reason);
             retval = oxcox.getData(ctx);
 
-            final int srcStore_id = retval.getFilestoreId().intValue();
-            ctx.setFilestoreId(srcStore_id);
+            // Check equality
+            int srcStore_id = retval.getFilestoreId().intValue();
+            ctx.setFilestoreId(Integer.valueOf(srcStore_id));
             if (srcStore_id == dst_filestore.getId().intValue()) {
-                throw new OXContextException("Src and dst store id is the same: " + dst_filestore);
+                throw new OXContextException("The identifiers for the source and destination storage are equal: " + dst_filestore);
             }
-            final String ctxdir = retval.getFilestore_name();
+
+            // Check storage name
+            String ctxdir = retval.getFilestore_name();
             if (ctxdir == null) {
                 throw new OXContextException("Unable to get filestore directory " + ctx.getIdAsString());
             }
 
-            final OXUtilStorageInterface oxu = OXUtilStorageInterface.getInstance();
-            final Filestore destFilestore = oxu.getFilestore(dst_filestore.getId().intValue());
+            OXUtilStorageInterface oxu = OXUtilStorageInterface.getInstance();
+            Filestore destFilestore = oxu.getFilestore(dst_filestore.getId().intValue());
+
+            // Check capacity
             if (!oxu.hasSpaceForAnotherContext(destFilestore)) {
                 throw new StorageException("Destination filestore does not have enough space for another context.");
             }
-            // get src and dst path from filestores
+
+            // Load it to ensure validity
+            String baseUri = destFilestore.getUrl();
             try {
-                final Filestore srcfilestore = oxu.getFilestore(srcStore_id);
-                URI sourceURI = new URI(srcfilestore.getUrl());
-                URI destURI = new URI(destFilestore.getUrl());
-                final StringBuilder src = builduppath(ctxdir, sourceURI);
-                final String dst = destURI.getPath();
-                final OXContextException contextException = new OXContextException("Unable to move filestore");
-                if (src == null) {
-                    LOGGER.error("src is null");
-                    throw contextException;
-                } else if (dst == null) {
-                    LOGGER.error("dst is null");
-                    throw contextException;
-                }
-                FilestoreDataMover fsdm = null;
-                boolean rsyncEnabled = "file".equalsIgnoreCase(sourceURI.getScheme()) && "file".equalsIgnoreCase(destURI.getScheme());
-                if (rsyncEnabled) {
-                    fsdm = new FilestoreDataMover(src.toString(), dst.toString(), ctx, dst_filestore, true);
-                } else {
-                    fsdm = new FilestoreDataMover(sourceURI.toString() + "/" + ctxdir, destURI.toString(), ctx, dst_filestore, false);
-                }
+                URI uri = FileStorages.getFullyQualifyingUriForContext(ctx.getId().intValue(), new java.net.URI(baseUri));
+                FileStorages.getFileStorageService().getFileStorage(uri);
+            } catch (OXException e) {
+                throw new StorageException(e.getMessage(), e);
+            } catch (URISyntaxException e) {
+                throw new StorageException("Invalid file storage URI: " + baseUri, e);
+            }
+
+            try {
+                // Initialize mover instance
+                FilestoreDataMover fsdm = FilestoreDataMover.newContextMover(oxu.getFilestore(srcStore_id), destFilestore, ctx);
+
+                // Enable context after processing
+                fsdm.addPostProcessTask(new PostProcessTask() {
+
+                    @Override
+                    public void perform(ExecutionException executionError) throws StorageException {
+                        if (null == executionError) {
+                            oxcox.enable(ctx);
+                        } else {
+                            LOGGER.warn("An execution error occurred during \"movefilestore\" for context {}. Context will stay disabled.", ctx.getId(), executionError.getCause());
+                        }
+                    }
+                });
+
+                // Schedule task
+                oxcox.disable(ctx, reason);
                 return TaskManager.getInstance().addJob(fsdm, "movefilestore", "move context " + ctx.getIdAsString() + " to filestore " + dst_filestore.getId(), ctx.getId());
             } catch (final StorageException e) {
                 throw new OXContextException(e);
-            } catch (final IOException e) {
-                throw new OXContextException(e);
             }
-        } catch (final URISyntaxException e) {
-            final StorageException storageException = new StorageException(e);
-            LOGGER.error("", storageException);
-            throw storageException;
         } catch (final NoSuchFilestoreException e) {
             LOGGER.error("", e);
             throw e;
@@ -1126,6 +1190,7 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
         }
 
         Context ret = oxcox.create(ctx, admin_user, createaccess, schemaSelectStrategy == null ? getDefaultSchemaSelectStrategy() : schemaSelectStrategy);
+
         if (isAnyPluginLoaded()) {
             PluginInterfaces pluginInterfaces = PluginInterfaces.getInstance();
             if (null != pluginInterfaces) {
@@ -1578,27 +1643,4 @@ public class OXContext extends OXContextCommonImpl implements OXContextInterface
     public boolean checkExists(final Context ctx, final Credentials credentials) throws RemoteException, InvalidDataException, StorageException, InvalidCredentialsException {
         return exists(ctx, credentials);
     }
-
-    @Override
-    public void checkCountsConsistency(boolean checkDatabaseCounts, boolean checkFilestoreCounts, Credentials credentials) throws RemoteException, StorageException, InvalidCredentialsException {
-        Credentials auth = credentials == null ? new Credentials("","") : credentials;
-        new BasicAuthenticator(context).doAuthentication(auth);
-
-        LOGGER.debug("Checking consistency for counters");
-
-        OXContextStorageInterface.getInstance().checkCountsConsistency(checkDatabaseCounts, checkFilestoreCounts);
-    }
-
-    /** Check for an empty string */
-    private static boolean isEmpty(final String string) {
-        if (null == string) {
-            return true;
-        }
-        final int len = string.length();
-        boolean isWhitespace = true;
-        for (int i = 0; isWhitespace && i < len; i++) {
-            isWhitespace = com.openexchange.java.Strings.isWhitespace(string.charAt(i));
-        }
-        return isWhitespace;
-    }
 }
