@@ -51,7 +51,6 @@ package com.openexchange.admin.storage.interfaces;
 
 import java.lang.reflect.Constructor;
 import java.lang.reflect.InvocationTargetException;
-import java.sql.Connection;
 import java.util.List;
 import java.util.Set;
 import com.openexchange.admin.daemons.ClientAdminThreadExtended;
@@ -60,6 +59,7 @@ import com.openexchange.admin.rmi.dataobjects.Credentials;
 import com.openexchange.admin.rmi.dataobjects.Database;
 import com.openexchange.admin.rmi.dataobjects.Filestore;
 import com.openexchange.admin.rmi.dataobjects.MaintenanceReason;
+import com.openexchange.admin.rmi.dataobjects.Quota;
 import com.openexchange.admin.rmi.dataobjects.SchemaSelectStrategy;
 import com.openexchange.admin.rmi.dataobjects.User;
 import com.openexchange.admin.rmi.dataobjects.UserModuleAccess;
@@ -159,18 +159,11 @@ public abstract class OXContextStorageInterface {
     /**
      * @param ctx Context with Filestore data set!
      * @throws StorageException
+     * @deprecated Use {@link OXUtilStorageInterface#changeFilestoreDataFor(Context)}
      */
+    @Deprecated
     public abstract void changeStorageData(final Context ctx) throws StorageException;
 
-    /**
-     * Gets the login mappings for specified context.
-     *
-     * @param ctx The context for which to load the mappings
-     * @return The available login mappings
-     * @throws StorageException If login mappings cannot be returned
-     */
-    public abstract Set<String> getLoginMappings(Context ctx) throws StorageException;
-
     /**
      * @param ctx
      * @return a context object
@@ -191,6 +184,15 @@ public abstract class OXContextStorageInterface {
      */
     public abstract void change(final Context ctx) throws StorageException;
 
+    /**
+     * Gets the configured quotas in given context.
+     *
+     * @param ctx The context
+     * @return The configured quota
+     * @throws StorageException If quotas cannot be returned
+     */
+    public abstract Quota[] listQuotas(Context ctx) throws StorageException;
+
     /**
      * Changes specified context's quota.
      *
@@ -359,23 +361,4 @@ public abstract class OXContextStorageInterface {
      */
     public abstract String createSchema(int targetClusterId) throws StorageException;
 
-    /**
-     * Checks the consistencies for the count tables
-     *
-     * @param configCon The connection to the ConfigDb
-     * @param checkDatabaseCounts Whether to check the counts related to context to database/schema associations
-     * @param checkFilestoreCounts Whether to check the counts related to context to filestore associations
-     * @throws StorageException If check fails
-     */
-    public abstract void checkCountsConsistency(Connection configCon, boolean checkDatabaseCounts, boolean checkFilestoreCounts) throws StorageException;
-
-    /**
-     * Checks the consistencies for the count tables
-     *
-     * @param checkDatabaseCounts Whether to check the counts related to context to database/schema associations
-     * @param checkFilestoreCounts Whether to check the counts related to context to filestore associations
-     * @throws StorageException If check fails
-     */
-    public abstract void checkCountsConsistency(boolean checkDatabaseCounts, boolean checkFilestoreCounts) throws StorageException;
-
 }
