@@ -149,27 +149,6 @@ public class Database extends EnforceableDataObject implements NameAndIdObject {
         this.scheme = schema;
     }
 
-    /**
-     * @param login
-     * @param password
-     * @param driver
-     * @param url
-     * @param id
-     * @param displayname
-     */
-    public Database(final String login, final String password, final String driver, final String url, final int id, final String displayname) {
-        super();
-        this.login = login;
-        this.password = password;
-        this.driver = driver;
-        this.url = url;
-        this.id = Integer.valueOf(id);
-        this.name = displayname;
-    }
-
-    /**
-     *
-     */
     public Database() {
         super();
         init();
@@ -356,22 +335,6 @@ public class Database extends EnforceableDataObject implements NameAndIdObject {
         return ret.toString();
     }
 
-    /**
-     * @param login
-     * @param password
-     * @param driver
-     * @param url
-     * @param scheme
-     */
-    public Database(final String login, final String password, final String driver, final String url, final String scheme) {
-        super();
-        this.login = login;
-        this.password = password;
-        this.driver = driver;
-        this.url = url;
-        this.scheme = scheme;
-    }
-
     /**
      * Initializes all members to the default values
      */
