@@ -7,22 +7,6 @@ CREATE TABLE configdb_sequence (
 
 INSERT INTO configdb_sequence VALUES (0);
 
-DROP PROCEDURE IF EXISTS get_configdb_id;
-DELIMITER //
-CREATE PROCEDURE get_configdb_id() NOT DETERMINISTIC MODIFIES SQL DATA
-BEGIN
-    DECLARE identifier INT4 UNSIGNED;
-    SET identifier = 0;
-    SELECT id INTO identifier FROM configdb_sequence FOR UPDATE;
-    IF 0 = identifier THEN
-        INSERT INTO configdb_sequence (id) VALUES (identifier);
-    END IF;
-    SET identifier = identifier + 1;
-    UPDATE configdb_sequence SET id = identifier;
-    SELECT identifier;
-END//
-DELIMITER ;
-
 CREATE TABLE db_pool (
     db_pool_id INT4 UNSIGNED NOT NULL,
     url VARCHAR(255) NOT NULL,
@@ -78,6 +62,13 @@ CREATE TABLE filestore (
     CONSTRAINT filestore_uri_unique UNIQUE(uri)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
 
+CREATE TABLE filestore2user (
+    cid INT4 UNSIGNED NOT NULL,
+    user INT4 UNSIGNED NOT NULL,
+    filestore_id INT4 UNSIGNED,
+    PRIMARY KEY (cid, user, filestore_id)
+) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
+
 CREATE TABLE server (
     server_id INT4 UNSIGNED NOT NULL,
     name VARCHAR(255) NOT NULL,
@@ -106,34 +97,7 @@ CREATE TABLE context_server2db_pool (
     FOREIGN KEY(`cid`) REFERENCES context (`cid`) ON DELETE CASCADE ON UPDATE CASCADE
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
 
-CREATE TABLE contexts_per_dbpool (
-    db_pool_id INT4 UNSIGNED NOT NULL,
-    count INT4 UNSIGNED NOT NULL,
-    PRIMARY KEY (db_pool_id)
+CREATE TABLE context2push_registration (
+    cid INT4 UNSIGNED NOT NULL,
+    PRIMARY KEY (cid)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
-
-CREATE TABLE contexts_per_filestore (
-    filestore_id INT4 UNSIGNED NOT NULL,
-    count INT4 UNSIGNED NOT NULL,
-    PRIMARY KEY (filestore_id)
-) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
-
-CREATE TABLE contexts_per_dbschema (
-    db_pool_id INT4 UNSIGNED NOT NULL,
-    schemaname VARCHAR(32) NOT NULL,
-    count INT4 UNSIGNED NOT NULL,
-    creating_date BIGINT(64) NOT NULL,
-    PRIMARY KEY (db_pool_id, schemaname)
-) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
-
-CREATE TABLE dbpool_lock (
-    db_pool_id INT4 UNSIGNED NOT NULL,
-    PRIMARY KEY (db_pool_id)
-) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
-
-CREATE TABLE dbschema_lock (
-    db_pool_id INT4 UNSIGNED NOT NULL,
-    schemaname VARCHAR(32) NOT NULL,
-    PRIMARY KEY (db_pool_id, schemaname)
-) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;
-
