@@ -74,7 +74,12 @@ public abstract class OXContextCommonImpl extends OXCommonImpl {
     /** The bundle context */
     protected final BundleContext context;
 
-    protected OXContextCommonImpl(final BundleContext context) throws StorageException {
+    /**
+     * Initializes a new {@link OXContextCommonImpl}.
+     *
+     * @param context The bundle context
+     */
+    protected OXContextCommonImpl(final BundleContext context) {
         super();
         this.context = context;
     }
@@ -181,7 +186,9 @@ public abstract class OXContextCommonImpl extends OXCommonImpl {
             LOGGER.error("", e);
             throw e;
         } catch (StorageException e) {
-            throw e;
+            LOGGER.error("", e);
+            // Eliminate nested root cause exceptions. These are mostly unknown to clients.
+            throw new StorageException(e.getMessage());
         }
     }
 
