@@ -193,6 +193,8 @@ public abstract class OXToolStorageInterface {
 
     public abstract boolean existsUser(final Context ctx, final int[] user_ids) throws StorageException;
 
+    public abstract boolean isGuestUser(Context ctx, int uid) throws StorageException;
+
     /**
      * This method will detect if a specified user exists. It check this through the user id and the
      * user name specified in the user object
@@ -413,6 +415,8 @@ public abstract class OXToolStorageInterface {
 
     public abstract String getUsernameByUserID(final Context ctx,final int user_id) throws StorageException;
 
+    public abstract boolean getIsGuestByUserID(final Context ctx, final int user_id) throws StorageException;
+
     public abstract boolean isContextAdmin(final Context ctx, final int user_id) throws StorageException;
 
     /**
@@ -481,6 +485,26 @@ public abstract class OXToolStorageInterface {
      */
     public abstract void changeAccessCombination(int filter, int addAccess, int removeAccess) throws StorageException;
 
+    /**
+     * Verifies whether the specified user is the owner of a master filestore and other users are using this filestore
+     * 
+     * @param context The context
+     * @param userId The user identifier
+     * @return true if the user is a master filestore owner AND other users are using this filestore; false otherwise
+     * @throws StorageException
+     */
+    public abstract boolean isMasterFilestoreOwner(Context context, int userId) throws StorageException;
+
+    /**
+     * Fetches the slave users of the master filestore
+     * 
+     * @param context
+     * @param userId
+     * @return
+     * @throws StorageException
+     */
+    public abstract Map<Integer, List<Integer>> fetchSlaveUsersOfMasterFilestore(Context context, int userId) throws StorageException;
+
     /**
      * Determines whether the specified context is the last one on the database schema
      * 
@@ -490,5 +514,5 @@ public abstract class OXToolStorageInterface {
      * @throws InvalidDataException if the specified context does not exist in any known database schema
      */
     public abstract boolean isLastContextInSchema(Context context) throws StorageException, InvalidDataException;
-
+    
 }
