@@ -229,7 +229,36 @@ public abstract class OXUserStorageInterface {
      * @param usrdata User containing user data.
      * @throws StorageException
      */
-    public abstract void change(final Context ctx,final User usrdata) throws StorageException;
+    public abstract void change(Context ctx, User usrdata) throws StorageException;
+
+    /**
+     * Enables denoted user.
+     *
+     * @param userId The user identifier
+     * @param context The context
+     * @throws StorageException If operation fails
+     */
+    public abstract void enableUser(int userId, Context ctx) throws StorageException;
+
+    /**
+     * Disables denoted user.
+     *
+     * @param userId The user identifier
+     * @param context The context
+     * @throws StorageException If operation fails
+     */
+    public abstract void disableUser(int userId, Context ctx) throws StorageException;
+
+    /**
+     * Switches user's <code>mailenabled</code> flag.
+     *
+     * @param userId The user identifier
+     * @param contextId The context identifier
+     * @param value The value
+     * @param con The connection to use
+     * @throws StorageException If operation fails
+     */
+    public abstract void setUserEnabled(int userId, int contextId, boolean value, Connection con) throws StorageException;
 
     /**
      * Changes last modified data in database
@@ -268,6 +297,18 @@ public abstract class OXUserStorageInterface {
      */
     public abstract User[] list(final Context ctx, final String search_pattern) throws StorageException;
 
+    /**
+     * Retrieve all user objects for a given context. Which match the given search_pattern
+     *
+     * @param ctx numerical context identifier
+     * @param includeGuests List guest users too
+     * @param excludeUsers List only guest users
+     * @return User[] containing user ids.
+     * @throws StorageException
+     *
+     */
+    public abstract User[] list(final Context ctx, final String search_pattern, final boolean includeGuests, final boolean excludeUsers) throws StorageException;
+
     /**
      * Retrieve all user objects for a given context, that match (case insensitive) the given search_pattern
      *
@@ -277,20 +318,31 @@ public abstract class OXUserStorageInterface {
      */
     public abstract User[] listCaseInsensitive(final Context ctx, final String search_pattern) throws StorageException;
 
+    /**
+     * Retrieve all user objects for a given context, that match (case insensitive) the given search_pattern
+     *
+     * @param ctx The context
+     * @param includeGuests List guest users too
+     * @param excludeUsers List only guest users
+     * @return User[] containing user identifier
+     * @throws StorageException
+     */
+    public abstract User[] listCaseInsensitive(final Context ctx, final String search_pattern, final boolean includeGuests, final boolean excludeUsers) throws StorageException;
+
     /**
      * Delete an user or multiple from given context in given connection
      */
-    public abstract void delete(final Context ctx, final User[] user_ids, final Connection write_ox_con ) throws StorageException;
+    public abstract void delete(final Context ctx, final User[] user_ids, Integer destUID, final Connection write_ox_con) throws StorageException;
 
     /**
      * Delete users in given context
      */
-    public abstract void delete( final Context ctx, final User[] users) throws StorageException;
+    public abstract void delete(final Context ctx, final User[] users, Integer destUser) throws StorageException;
 
     /**
      * Delete one user in given context
      */
-    public abstract void delete( final Context ctx, final User user) throws StorageException;
+    public abstract void delete(final Context ctx, final User user, Integer destUser) throws StorageException;
 
     /**
      * Fetch all data from current user  and add it to "del_user"
