@@ -61,9 +61,7 @@ import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.HashMap;
 import java.util.List;
-import java.util.Map;
 import java.util.SortedMap;
 import java.util.TreeMap;
 import com.openexchange.admin.daemons.ClientAdminThread;
@@ -84,7 +82,6 @@ import com.openexchange.config.ConfigurationService;
 import com.openexchange.database.AssignmentInsertData;
 import com.openexchange.database.Databases;
 import com.openexchange.exception.OXException;
-import com.openexchange.tools.file.external.QuotaFileStorages;
 import com.openexchange.tools.pipesnfilters.DataSource;
 import com.openexchange.tools.pipesnfilters.Filter;
 import com.openexchange.tools.pipesnfilters.PipesAndFiltersException;
@@ -96,6 +93,8 @@ public class OXContextMySQLStorageCommon {
 
     private static final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(OXContextMySQLStorageCommon.class);
 
+    private final OXUtilMySQLStorageCommon oxutilcommon;
+
     private static AdminCache cache = null;
 
     private static PropertyHandler prop = null;
@@ -105,57 +104,8 @@ public class OXContextMySQLStorageCommon {
         prop = cache.getProperties();
     }
 
-    private static interface StartNumberProvider {
-
-        int getStartValue();
-    }
-
-
-    // -----------------------------------------------------------------------------------------------------------------------------
-
-    private final OXUtilMySQLStorageCommon oxutilcommon;
-    private final Map<String, StartNumberProvider> startValues;
-
     public OXContextMySQLStorageCommon() {
-        super();
         oxutilcommon = new OXUtilMySQLStorageCommon();
-
-        Map<String, StartNumberProvider> startValues = new HashMap<String, StartNumberProvider>(4);
-        startValues.put("sequence_folder", new StartNumberProvider() {
-
-            @Override
-            public int getStartValue() {
-                // below id 20 is reserved
-                return 20;
-            }
-        });
-        startValues.put("sequence_uid_number", new StartNumberProvider() {
-
-            @Override
-            public int getStartValue() {
-                int startnum = Integer.parseInt(prop.getUserProp(AdminProperties.User.UID_NUMBER_START, "-1"));
-                if (startnum > 0) {
-                    // we use the uid number feature
-                    // set the start number in the sequence for uid_numbers
-                    return startnum;
-                }
-                return 0;
-            }
-        });
-        startValues.put("sequence_gid_number", new StartNumberProvider() {
-
-            @Override
-            public int getStartValue() {
-                int startnum = Integer.parseInt(prop.getGroupProp(AdminProperties.Group.GID_NUMBER_START, "-1"));
-                if (startnum > 0) {
-                    // we use the gid number feature
-                    // set the start number in the sequence for gid_numbers
-                    return startnum;
-                }
-                return 0;
-            }
-        });
-        this.startValues = startValues;
     }
 
     // TODO: The average size parameter can be removed if we have an new property handler which can
@@ -195,7 +145,7 @@ public class OXContextMySQLStorageCommon {
                 cs.setFilestore_name(rs.getString(5)); //filestorename
                 long quota_max = rs.getLong(6); //quota max
                 if (quota_max != -1) {
-                    quota_max /= Math.pow(2, 20);
+                    quota_max = quota_max >> 20;
                     // set quota max also in context setup object
                     cs.setMaxQuota(quota_max);
                 }
@@ -232,9 +182,7 @@ public class OXContextMySQLStorageCommon {
 
             oxdb_read = cache.getConnectionForContext(context_id);
 
-            boolean hasUserColumn = QuotaFileStorages.hasUserColumn(oxdb_read, context_id);
-
-            prep = oxdb_read.prepareStatement(hasUserColumn ? "SELECT filestore_usage.used FROM filestore_usage WHERE filestore_usage.cid = ? AND filestore_usage.user = 0" : "SELECT filestore_usage.used FROM filestore_usage WHERE filestore_usage.cid = ?");
+            prep = oxdb_read.prepareStatement("SELECT filestore_usage.used FROM filestore_usage WHERE filestore_usage.cid = ? AND filestore_usage.user = 0");
             prep.setInt(1, context_id);
             rs = prep.executeQuery();
 
@@ -244,7 +192,7 @@ public class OXContextMySQLStorageCommon {
             }
             rs.close();
             prep.close();
-            quota_used /= Math.pow(2, 20);
+            quota_used = quota_used >> 20;
             // set used quota in context setup
             cs.setUsedQuota(quota_used);
 
@@ -254,8 +202,6 @@ public class OXContextMySQLStorageCommon {
             cs.setId(context_id);
             loadDynamicAttributes(oxdb_read, cs);
             return cs;
-        } catch (OXException e) {
-            throw new StorageException(e.getMessage(), e);
         } finally {
             Databases.closeSQLStuff(prep);
             if (oxdb_read != null) {
@@ -419,7 +365,7 @@ public class OXContextMySQLStorageCommon {
         if (otherContexts.length == 0) {
             Database db = OXToolStorageInterface.getInstance().loadDatabaseById(poolId);
             db.setScheme(dbSchema);
-            OXUtilMySQLStorageCommon.deleteDatabase(db,con);
+            OXUtilMySQLStorageCommon.deleteDatabase(db);
         }
     }
 
@@ -429,38 +375,21 @@ public class OXContextMySQLStorageCommon {
         try {
             // This creates a lock on context_server2db_pool on the rows with contexts in the same schema. Concurrent create and delete of
             // context can cause removed schemas while creating a context in it. This can not happen anymore with the introduced lock.
-            int poolId = pool.getWritePool(contextId);
-            String dbSchema = pool.getSchemaName(contextId);
-            int filestoreId = getFilestoreIdFor(con, contextId);
-
+            final int poolId = pool.getWritePool(contextId);
             pool.lock(con, poolId);
-
-            if (0 != filestoreId) {
-                stmt = con.prepareStatement("UPDATE contexts_per_filestore SET count=count-1 WHERE filestore_id=?");
-                stmt.setInt(1, filestoreId);
-                stmt.executeUpdate();
-                Databases.closeSQLStuff(stmt);
-                stmt = null;
-            }
-
-            // Delete association from "context_server2db_pool" table
+            final String dbSchema = pool.getSchemaName(contextId);
             pool.deleteAssignment(con, contextId);
-
             deleteEmptySchema(con, poolId, dbSchema);
-
             log.debug("Deleting login2context entries for context {}", I(contextId));
             stmt = con.prepareStatement("DELETE FROM login2context WHERE cid=?");
             stmt.setInt(1, contextId);
             stmt.executeUpdate();
-            Databases.closeSQLStuff(stmt);
-            stmt = null;
-
+            stmt.close();
             log.debug("Deleting context entry for context {}", I(contextId));
             stmt = con.prepareStatement("DELETE FROM context WHERE cid=?");
             stmt.setInt(1, contextId);
             stmt.executeUpdate();
-            Databases.closeSQLStuff(stmt);
-            stmt = null;
+            stmt.close();
         } catch (PoolException e) {
             log.error(e.getMessage(), e);
             throw new StorageException(e.getMessage(), e);
@@ -472,23 +401,6 @@ public class OXContextMySQLStorageCommon {
         }
     }
 
-    private int getFilestoreIdFor(Connection con, int contextId) throws SQLException {
-        PreparedStatement stmt = null;
-        ResultSet rs = null;
-        try {
-            stmt = con.prepareStatement("SELECT filestore_id FROM context WHERE cid=?");
-            stmt.setInt(1, contextId);
-            rs = stmt.executeQuery();
-            int filestoreId = 0;
-            if (rs.next()) {
-                filestoreId = rs.getInt(1);
-            }
-            return filestoreId;
-        } finally {
-            Databases.closeSQLStuff(rs, stmt);
-        }
-    }
-
     private String[] determineSequenceTables(final Connection con) throws SQLException {
         PreparedStatement stmt = null;
         ResultSet result = null;
@@ -526,7 +438,6 @@ public class OXContextMySQLStorageCommon {
             db.setRead_id(db.getId());
         }
         fillContextTable(ctx, con);
-        incrementContextsPerFilestoreTable(ctx, con);
 
         try {
             final int serverId = ClientAdminThread.cache.getServerId();
@@ -541,7 +452,12 @@ public class OXContextMySQLStorageCommon {
                 }
                 @Override
                 public int getReadPoolId() {
-                    return i(db.getRead_id());
+                    Integer readId = db.getRead_id();
+                    if (null == readId) {
+                        // Hints to a pool w/o a slave; return write-pool identifier instead
+                        return getWritePoolId();
+                    }
+                    return i(readId);
                 }
                 @Override
                 public int getWritePoolId() {
@@ -627,8 +543,30 @@ public class OXContextMySQLStorageCommon {
     }
 
     private int modifyStartValue(final String tableName) {
-        StartNumberProvider startNumberProvider = startValues.get(tableName);
-        return null == startNumberProvider ? 0 : startNumberProvider.getStartValue();
+        int retval = 0;
+        if ("sequence_folder".equals(tableName)) {
+            // below id 20 is reserved
+            retval = 20;
+        }
+        // check for the uid number feature
+        if ("sequence_uid_number".equals(tableName)) {
+            final int startnum = Integer.parseInt(prop.getUserProp(AdminProperties.User.UID_NUMBER_START, "-1"));
+            if (startnum > 0) {
+                // we use the uid number feature
+                // set the start number in the sequence for uid_numbers
+                retval = startnum;
+            }
+        }
+        // check for the gid number feature
+        if ("sequence_gid_number".equals(tableName)){
+            final int startnum = Integer.parseInt(prop.getGroupProp(AdminProperties.Group.GID_NUMBER_START, "-1"));
+            if (startnum > 0) {
+                // we use the gid number feature
+                // set the start number in the sequence for gid_numbers
+                retval = startnum;
+            }
+        }
+        return retval;
     }
 
     /**
@@ -659,7 +597,7 @@ public class OXContextMySQLStorageCommon {
             // quota is in MB, but we store in Byte
             long quota_max_temp = ctx.getMaxQuota().longValue();
             if (quota_max_temp != -1) {
-                quota_max_temp *= Math.pow(2, 20);
+                quota_max_temp = quota_max_temp << 20;
             }
             stmt.setLong(6, quota_max_temp);
             stmt.executeUpdate();
@@ -676,26 +614,6 @@ public class OXContextMySQLStorageCommon {
         }
     }
 
-    /**
-     * <code>INSERT</code>s the data row into the "context" table.
-     *
-     * @param ctx The context newly using a filestore
-     * @param configdbCon A connection to the configdb
-     * @throws StorageException If a general SQL error occurs
-     */
-    private final void incrementContextsPerFilestoreTable(final Context ctx, final Connection configdbCon) throws StorageException {
-        PreparedStatement stmt = null;
-        try {
-            stmt = configdbCon.prepareStatement("UPDATE contexts_per_filestore SET count=count+1 WHERE filestore_id=?");
-            stmt.setInt(1, ctx.getFilestoreId().intValue());
-            stmt.executeUpdate();
-        } catch (final SQLException e) {
-            throw new StorageException(e.getMessage(), e);
-        } finally {
-            Databases.closeSQLStuff(stmt);
-        }
-    }
-
     public void fillLogin2ContextTable(Context ctx, Connection configdb_write_con) throws SQLException, StorageException {
         int contextId = ctx.getId().intValue();
         for (String mapping : ctx.getLoginMappings()) {
