@@ -96,16 +96,6 @@ public class OXAdminPoolDBPool implements OXAdminPoolInterface {
         return con;
     }
 
-    @Override
-    public Connection getConnectionForConfigDBNoTimeout() throws PoolException {
-        try {
-            return getService().getForUpdateTask();
-        } catch (OXException e) {
-            log.error("Error pickup no-timeout configdb database write connection from pool!", e);
-            throw new PoolException(e.getMessage());
-        }
-    }
-
     @Override
     public Connection getConnectionForContext(int contextId) throws PoolException {
         final Connection con;
@@ -144,12 +134,8 @@ public class OXAdminPoolDBPool implements OXAdminPoolInterface {
 
     @Override
     public boolean pushConnectionForConfigDB(Connection con) throws PoolException {
-        if (null == con) {
-            return false;
-        }
-
         try {
-            if (!con.getAutoCommit() && !con.isClosed()) {
+            if (con != null && !con.getAutoCommit() && !con.isClosed()) {
                 con.setAutoCommit(true);
             }
         } catch (SQLException e) {
@@ -161,32 +147,10 @@ public class OXAdminPoolDBPool implements OXAdminPoolInterface {
         return true;
     }
 
-    @Override
-    public boolean pushConnectionForConfigDBNoTimeout(Connection con) throws PoolException {
-        if (null == con) {
-            return false;
-        }
-        try {
-            if (!con.getAutoCommit() && !con.isClosed()) {
-                con.setAutoCommit(true);
-            }
-        } catch (SQLException e) {
-            log.error("Error pushing no-timeout configdb write connection to pool!", e);
-            throw new PoolException(e.getMessage());
-        } finally {
-            getService().backForUpdateTask(con);
-        }
-        return true;
-    }
-
     @Override
     public boolean pushConnectionForContext(int contextId, Connection con) throws PoolException {
-        if (null == con) {
-            return false;
-        }
-
         try {
-            if (!con.getAutoCommit() && !con.isClosed()) {
+            if (con != null && !con.getAutoCommit() && !con.isClosed()) {
                 con.setAutoCommit(true);
             }
         } catch (SQLException e) {
@@ -200,12 +164,8 @@ public class OXAdminPoolDBPool implements OXAdminPoolInterface {
 
     @Override
     public boolean pushConnectionForContextAfterReading(int contextId, Connection con) throws PoolException {
-        if (null == con) {
-            return false;
-        }
-
         try {
-            if (!con.getAutoCommit() && !con.isClosed()) {
+            if (con != null && !con.getAutoCommit() && !con.isClosed()) {
                 con.setAutoCommit(true);
             }
         } catch (SQLException e) {
@@ -219,12 +179,8 @@ public class OXAdminPoolDBPool implements OXAdminPoolInterface {
 
     @Override
     public boolean pushConnectionForContextNoTimeout(int contextId, Connection con) throws PoolException {
-        if (null == con) {
-            return false;
-        }
-
         try {
-            if (!con.getAutoCommit() && !con.isClosed()) {
+            if (null != con && !con.getAutoCommit() && !con.isClosed()) {
                 con.setAutoCommit(true);
             }
         } catch (SQLException e) {
@@ -238,12 +194,8 @@ public class OXAdminPoolDBPool implements OXAdminPoolInterface {
 
     @Override
     public boolean pushConnection(int poolId, Connection con) throws PoolException {
-        if (null == con) {
-            return false;
-        }
-
         try {
-            if (!con.getAutoCommit() && !con.isClosed()) {
+            if (null != con && !con.getAutoCommit() && !con.isClosed()) {
                 con.setAutoCommit(true);
             }
         } catch (SQLException e) {
@@ -362,7 +314,7 @@ public class OXAdminPoolDBPool implements OXAdminPoolInterface {
         try {
             getService().lock(con, writePoolId);
         } catch (OXException e) {
-            log.error("Error locking database pool {}", writePoolId, e);
+            log.error("Error locking context_server2db_pool table", e);
             throw new PoolException(e.getMessage());
         }
     }
