@@ -61,8 +61,6 @@ public interface OXAdminPoolInterface {
 
     Connection getConnectionForConfigDB() throws PoolException;
 
-    Connection getConnectionForConfigDBNoTimeout() throws PoolException;
-
     Connection getConnectionForContext(int contextId) throws PoolException;
 
     Connection getConnectionForContextNoTimeout(int contextId) throws PoolException;
@@ -71,8 +69,6 @@ public interface OXAdminPoolInterface {
 
     boolean pushConnectionForConfigDB(Connection con) throws PoolException;
 
-    boolean pushConnectionForConfigDBNoTimeout(Connection con) throws PoolException;
-
     boolean pushConnectionForContext(int contextId, Connection con) throws PoolException;
 
     boolean pushConnectionForContextAfterReading(int contextId, Connection con) throws PoolException;
