@@ -173,6 +173,8 @@ public class AdminCache {
      */
     private boolean contextAuthenticationDisabled = false;
 
+    private boolean allowMasterOverride = false;
+
     // master credentials for authenticating master admin
     private Credentials masterCredentials = null;
 
@@ -424,18 +426,10 @@ public class AdminCache {
         return this.pool.getConnectionForConfigDB();
     }
 
-    public Connection getConnectionForConfigDBNoTimeout() throws PoolException {
-        return this.pool.getConnectionForConfigDBNoTimeout();
-    }
-
     public boolean pushConnectionForConfigDB(final Connection con) throws PoolException {
         return this.pool.pushConnectionForConfigDB(con);
     }
 
-    public boolean pushConnectionForConfigDBNoTimeout(final Connection con) throws PoolException {
-        return this.pool.pushConnectionForConfigDBNoTimeout(con);
-    }
-
     public int getServerId() throws PoolException {
         return this.pool.getServerId();
     }
@@ -575,7 +569,7 @@ public class AdminCache {
      */
     public String encryptPassword(final PasswordMechObject user) throws StorageException, NoSuchAlgorithmException, UnsupportedEncodingException {
         String passwordMech = user.getPasswordMech();
-        if (isEmpty(passwordMech) || "null".equals(toLowerCase(passwordMech))) {
+        if (com.openexchange.java.Strings.isEmpty(passwordMech) || "null".equals(com.openexchange.java.Strings.toLowerCase(passwordMech))) {
             String pwmech = getProperties().getUserProp(AdminProperties.User.DEFAULT_PASSWORD_MECHANISM, "SHA");
             pwmech = "{" + pwmech + "}";
             if (pwmech.equalsIgnoreCase(PasswordMechObject.CRYPT_MECH)) {
@@ -615,6 +609,9 @@ public class AdminCache {
 
         contextAuthenticationDisabled = Boolean.parseBoolean(context_auth_disabled);
         log.debug("ContextAuthentication mechanism disabled: {}", contextAuthenticationDisabled);
+
+        allowMasterOverride = Boolean.parseBoolean(this.prop.getProp("MASTER_ACCOUNT_OVERRIDE", "false"));
+        log.debug("Master override: {}", allowMasterOverride);
     }
 
     private void readMasterCredentials(final ConfigurationService service) throws OXGenericException {
@@ -629,9 +626,12 @@ public class AdminCache {
                         if (line.indexOf(':') >= 0) {
                             // ok seems to be a line with user:pass entry
                             final String[] user_pass_combination = line.split(":");
-                            if (user_pass_combination.length > 0) {
-                                this.masterCredentials = new Credentials(user_pass_combination[0], user_pass_combination[1]);
-                                this.log.debug("Master credentials successfully set!");
+                            if (user_pass_combination.length == 3) {
+                                this.masterCredentials = new Credentials(user_pass_combination[0], user_pass_combination[2]);
+                                this.masterCredentials.setPasswordMech(user_pass_combination[1]);
+                                log.debug("Master credentials successfully set!");
+                            } else {
+                                throw new OXGenericException("Invalid mpasswd format.");
                             }
                         }
                     }
@@ -672,19 +672,19 @@ public class AdminCache {
     }
 
     public void closeConfigDBSqlStuff(final Connection con, final PreparedStatement stmt) {
-        if (stmt != null) {
-            try {
+        try {
+            if (stmt != null) {
                 stmt.close();
-            } catch (final SQLException e) {
-                log.error("Error closing statement", e);
             }
+        } catch (final SQLException e) {
+            log.error("Error closing statement", e);
         }
-        if (con != null) {
-            try {
+        try {
+            if (con != null) {
                 pushConnectionForConfigDB(con);
-            } catch (final PoolException exp) {
-                log.error("Pool Error pushing connection to pool!", exp);
             }
+        } catch (final PoolException exp) {
+            log.error("Pool Error pushing connection to pool!", exp);
         }
     }
 
@@ -710,34 +710,11 @@ public class AdminCache {
         return masterAuthenticationDisabled || (getMasterCredentials() != null && getMasterCredentials().getLogin().equals(auth.getLogin()));
     }
 
-    /** ASCII-wise to lower-case */
-    private static String toLowerCase(final CharSequence chars) {
-        if (null == chars) {
-            return null;
-        }
-        final int length = chars.length();
-        final StringBuilder builder = new StringBuilder(length);
-        for (int i = 0; i < length; i++) {
-            final char c = chars.charAt(i);
-            builder.append((c >= 'A') && (c <= 'Z') ? (char) (c ^ 0x20) : c);
-        }
-        return builder.toString();
-    }
-
-    /** Check for an empty string */
-    private static boolean isEmpty(final String string) {
-        if (null == string) {
-            return true;
-        }
-        final int len = string.length();
-        boolean isWhitespace = true;
-        for (int i = 0; isWhitespace && i < len; i++) {
-            isWhitespace = com.openexchange.java.Strings.isWhitespace(string.charAt(i));
-        }
-        return isWhitespace;
-    }
-
     public void reloadMasterCredentials(ConfigurationService configService) throws OXGenericException {
         readMasterCredentials(configService);
     }
+
+    public boolean isAllowMasterOverride() {
+        return allowMasterOverride;
+    }
 }
